==> jc-1.4.0.tar.gz: gnu/xml/util/XHTMLWriter.h <==
// public class gnu.xml.util.XHTMLWriter

// class file dependencies
// @dep_class cf361ec4595bcf34 gnu_xml_util_XHTMLWriter
// @dep_class d4916ea70623e353 gnu_xml_util_XMLWriter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_util_XMLWriter

#include "gnu/xml/util/XMLWriter.h"

#ifndef _JC_gnu_xml_util_XHTMLWriter_H_
#define _JC_gnu_xml_util_XHTMLWriter_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_util_XHTMLWriter$sub_refs	_jc_gnu_xml_util_XHTMLWriter$sub_refs;
typedef struct _jc_gnu_xml_util_XHTMLWriter$sub_nonrefs	_jc_gnu_xml_util_XHTMLWriter$sub_nonrefs;
typedef struct _jc_gnu_xml_util_XHTMLWriter$refs	_jc_gnu_xml_util_XHTMLWriter$refs;
typedef struct _jc_gnu_xml_util_XHTMLWriter$nonrefs	_jc_gnu_xml_util_XHTMLWriter$nonrefs;
typedef struct _jc_gnu_xml_util_XHTMLWriter$object	_jc_gnu_xml_util_XHTMLWriter$object;

typedef const struct _jc_gnu_xml_util_XHTMLWriter$vmethods	_jc_gnu_xml_util_XHTMLWriter$vmethods;
typedef const struct _jc_gnu_xml_util_XHTMLWriter$vtable	_jc_gnu_xml_util_XHTMLWriter$vtable;
typedef const struct _jc_gnu_xml_util_XHTMLWriter$vtype	_jc_gnu_xml_util_XHTMLWriter$vtype;

// Constructors
extern void _jc_gnu_xml_util_XHTMLWriter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_util_XHTMLWriter$object *);
extern void _jc_gnu_xml_util_XHTMLWriter$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_xml_util_XHTMLWriter$object *, struct _jc_java_io_OutputStream$object *);
extern void _jc_gnu_xml_util_XHTMLWriter$method$_init$514f7e161933236e(_jc_env *, struct _jc_gnu_xml_util_XHTMLWriter$object *, struct _jc_java_io_Writer$object *);
extern void _jc_gnu_xml_util_XHTMLWriter$method$_init$6663225f81e77422(_jc_env *, struct _jc_gnu_xml_util_XHTMLWriter$object *, struct _jc_java_io_Writer$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_xml_util_XHTMLWriter$vmethods {
};

// Vtable
struct _jc_gnu_xml_util_XHTMLWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_XMLWriter$vmethods	gnu_xml_util_XMLWriter;
	_jc_gnu_xml_util_XHTMLWriter$vmethods	gnu_xml_util_XHTMLWriter;
};

// Vtype
struct _jc_gnu_xml_util_XHTMLWriter$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_XHTMLWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_XHTMLWriter$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_XHTMLWriter$refs {
    _jc_gnu_xml_util_XHTMLWriter$sub_refs	gnu_xml_util_XHTMLWriter;
    _jc_gnu_xml_util_XMLWriter$sub_refs	gnu_xml_util_XMLWriter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_XHTMLWriter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_XHTMLWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_XMLWriter$sub_nonrefs	gnu_xml_util_XMLWriter;
    _jc_gnu_xml_util_XHTMLWriter$sub_nonrefs	gnu_xml_util_XHTMLWriter;
};

// Object instance structure
struct _jc_gnu_xml_util_XHTMLWriter$object {
	_jc_gnu_xml_util_XHTMLWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_XHTMLWriter$vtype	*vtype;
	_jc_gnu_xml_util_XHTMLWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_XHTMLWriter$vtype _jc_gnu_xml_util_XHTMLWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_XHTMLWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_XHTMLWriter$class_object;

#endif	/* _JC_gnu_xml_util_XHTMLWriter_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/util/XHTMLWriter.h <==
// public class gnu.xml.util.XHTMLWriter

// class file dependencies
// @dep_class cf361ec4595bcf34 gnu_xml_util_XHTMLWriter
// @dep_class d4916ea70623e353 gnu_xml_util_XMLWriter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_util_XMLWriter

#include "gnu/xml/util/XMLWriter.h"

#ifndef _JC_gnu_xml_util_XHTMLWriter_H_
#define _JC_gnu_xml_util_XHTMLWriter_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_util_XHTMLWriter$sub_refs	_jc_gnu_xml_util_XHTMLWriter$sub_refs;
typedef struct _jc_gnu_xml_util_XHTMLWriter$sub_nonrefs	_jc_gnu_xml_util_XHTMLWriter$sub_nonrefs;
typedef struct _jc_gnu_xml_util_XHTMLWriter$refs	_jc_gnu_xml_util_XHTMLWriter$refs;
typedef struct _jc_gnu_xml_util_XHTMLWriter$nonrefs	_jc_gnu_xml_util_XHTMLWriter$nonrefs;
typedef struct _jc_gnu_xml_util_XHTMLWriter$object	_jc_gnu_xml_util_XHTMLWriter$object;

typedef const struct _jc_gnu_xml_util_XHTMLWriter$vmethods	_jc_gnu_xml_util_XHTMLWriter$vmethods;
typedef const struct _jc_gnu_xml_util_XHTMLWriter$vtable	_jc_gnu_xml_util_XHTMLWriter$vtable;
typedef const struct _jc_gnu_xml_util_XHTMLWriter$vtype	_jc_gnu_xml_util_XHTMLWriter$vtype;

// Constructors
extern void _jc_gnu_xml_util_XHTMLWriter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_util_XHTMLWriter$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_XHTMLWriter$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_xml_util_XHTMLWriter$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_XHTMLWriter$method$_init$514f7e161933236e(_jc_env *, struct _jc_gnu_xml_util_XHTMLWriter$object *, struct _jc_java_io_Writer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_util_XHTMLWriter$method$_init$6663225f81e77422(_jc_env *, struct _jc_gnu_xml_util_XHTMLWriter$object *, struct _jc_java_io_Writer$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_util_XHTMLWriter$vmethods {
};

// Vtable
struct _jc_gnu_xml_util_XHTMLWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_util_XMLWriter$vmethods	gnu_xml_util_XMLWriter;
	_jc_gnu_xml_util_XHTMLWriter$vmethods	gnu_xml_util_XHTMLWriter;
};

// Vtype
struct _jc_gnu_xml_util_XHTMLWriter$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_XHTMLWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_XHTMLWriter$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_XHTMLWriter$refs {
    _jc_gnu_xml_util_XHTMLWriter$sub_refs	gnu_xml_util_XHTMLWriter;
    _jc_gnu_xml_util_XMLWriter$sub_refs	gnu_xml_util_XMLWriter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_XHTMLWriter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_XHTMLWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_util_XMLWriter$sub_nonrefs	gnu_xml_util_XMLWriter;
    _jc_gnu_xml_util_XHTMLWriter$sub_nonrefs	gnu_xml_util_XHTMLWriter;
};

// Object instance structure
struct _jc_gnu_xml_util_XHTMLWriter$object {
	_jc_gnu_xml_util_XHTMLWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_XHTMLWriter$vtype	*vtype;
	_jc_gnu_xml_util_XHTMLWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_XHTMLWriter$vtype _jc_gnu_xml_util_XHTMLWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_XHTMLWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_XHTMLWriter$class_object;

#endif	/* _JC_gnu_xml_util_XHTMLWriter_H_ */
